@@ -133,10 +133,12 @@ sub query_execute {
     my($self, $sth, @qmarks) = @_;
 
     for my $attempt (0..$self->{reconnect_attempts}) {
+        #warn "Exe: @qmarks"; # TODO
         if(! $sth->execute(@qmarks)) {
                 # Exe failed
                 # warn "Log4perl: DBI->execute failed $DBI::errstr, \n".
                 #                  "on $self->{SQL}\n@qmarks";
+                #warn "Exe: failed: $DBI::errstr"; # TODO
                 if($attempt == $self->{reconnect_attempts}) {
                     croak "Log4perl: DBI appender failed to reconnect to database " .
                           "after $self->{reconnect_attempts} attempt" .
@@ -145,23 +147,30 @@ sub query_execute {
             if(! $self->{dbh}->ping()) {
                 # Ping failed, try to reconnect
                 if($attempt) {
+                    #warn "Sleeping"; # TODO
                     sleep($self->{reconnect_sleep}) if $self->{reconnect_sleep};
                 }
 
                 eval {
-                    #warn "Reconnecting to DB";
+                    #warn "Reconnecting to DB"; # TODO
                     $self->{dbh} = $self->{connect}->();
                 };
+            }
 
+            if ($self->{usePreparedStmt}) {
                 $sth = $self->create_statement($self->{SQL});
                 $self->{sth} = $sth if $self->{sth};
-                next;
+            } else {
+                #warn "Pending stmt: $self->{pending_stmt}"; #TODO
+                $sth = $self->create_statement($self->{pending_stmt});
             }
+
+            next;
         }
         return 1;
     }
     croak "Log4perl: DBI->execute failed $DBI::errstr, \n".
-          "on $self->{SQL}\n@qmarks";
+          "on $self->{SQL}\n @qmarks";
 }
 
 sub calculate_bind_values {
@@ -249,6 +258,8 @@ sub check_buffer {
         while (@{$self->{BUFFER}}) {
             my ($stmt, $qmarks) = splice (@{$self->{BUFFER}},0,2);
 
+            $self->{pending_stmt} = $stmt;
+
                 #reuse the sth if the stmt doesn't change
             if ($stmt ne $prev_stmt) {
                 $sth->finish if $sth;
